ios_native_sidebar library

Classes

NativeSidebar
A widget that renders a native iPadOS/iOS sidebar using UISplitViewController with iOS 26 liquid glass aesthetics.
NativeSidebarItem
A single entry shown in the native sidebar list.
NativeSidebarState
Describes the current state of the native sidebar passed to the builder.

Typedefs

NativeSidebarBuilder = Widget Function(BuildContext context, NativeSidebarState state)